from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.Gaming
import win32more.Windows.Win32.System.Com
import win32more.Windows.Win32.System.WinRT
ID_GDF_XML_STR: String = '__GDF_XML'
ID_GDF_THUMBNAIL_STR: String = '__GDF_THUMBNAIL'
@winfunctype('api-ms-win-gaming-expandedresources-l1-1-0.dll')
def HasExpandedResources(hasExpandedResources: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('api-ms-win-gaming-expandedresources-l1-1-0.dll')
def GetExpandedResourceExclusiveCpuCount(exclusiveCpuCount: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('api-ms-win-gaming-expandedresources-l1-1-0.dll')
def ReleaseExclusiveCpuSets() -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('api-ms-win-gaming-deviceinformation-l1-1-0.dll')
def GetGamingDeviceModelInformation(information: POINTER(win32more.Windows.Win32.Gaming.GAMING_DEVICE_MODEL_INFORMATION)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('api-ms-win-gaming-tcui-l1-1-0.dll')
def ShowGameInviteUI(serviceConfigurationId: win32more.Windows.Win32.System.WinRT.HSTRING, sessionTemplateName: win32more.Windows.Win32.System.WinRT.HSTRING, sessionId: win32more.Windows.Win32.System.WinRT.HSTRING, invitationDisplayText: win32more.Windows.Win32.System.WinRT.HSTRING, completionRoutine: win32more.Windows.Win32.Gaming.GameUICompletionRoutine, context: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('api-ms-win-gaming-tcui-l1-1-0.dll')
def ShowPlayerPickerUI(promptDisplayText: win32more.Windows.Win32.System.WinRT.HSTRING, xuids: POINTER(win32more.Windows.Win32.System.WinRT.HSTRING), xuidsCount: UIntPtr, preSelectedXuids: POINTER(win32more.Windows.Win32.System.WinRT.HSTRING), preSelectedXuidsCount: UIntPtr, minSelectionCount: UIntPtr, maxSelectionCount: UIntPtr, completionRoutine: win32more.Windows.Win32.Gaming.PlayerPickerUICompletionRoutine, context: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('api-ms-win-gaming-tcui-l1-1-0.dll')
def ShowProfileCardUI(targetUserXuid: win32more.Windows.Win32.System.WinRT.HSTRING, completionRoutine: win32more.Windows.Win32.Gaming.GameUICompletionRoutine, context: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('api-ms-win-gaming-tcui-l1-1-0.dll')
def ShowChangeFriendRelationshipUI(targetUserXuid: win32more.Windows.Win32.System.WinRT.HSTRING, completionRoutine: win32more.Windows.Win32.Gaming.GameUICompletionRoutine, context: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('api-ms-win-gaming-tcui-l1-1-0.dll')
def ShowTitleAchievementsUI(titleId: UInt32, completionRoutine: win32more.Windows.Win32.Gaming.GameUICompletionRoutine, context: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('api-ms-win-gaming-tcui-l1-1-0.dll')
def ProcessPendingGameUI(waitForCompletion: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('api-ms-win-gaming-tcui-l1-1-0.dll')
def TryCancelPendingGameUI() -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('api-ms-win-gaming-tcui-l1-1-1.dll')
def CheckGamingPrivilegeWithUI(privilegeId: UInt32, scope: win32more.Windows.Win32.System.WinRT.HSTRING, policy: win32more.Windows.Win32.System.WinRT.HSTRING, friendlyMessage: win32more.Windows.Win32.System.WinRT.HSTRING, completionRoutine: win32more.Windows.Win32.Gaming.GameUICompletionRoutine, context: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('api-ms-win-gaming-tcui-l1-1-1.dll')
def CheckGamingPrivilegeSilently(privilegeId: UInt32, scope: win32more.Windows.Win32.System.WinRT.HSTRING, policy: win32more.Windows.Win32.System.WinRT.HSTRING, hasPrivilege: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('api-ms-win-gaming-tcui-l1-1-2.dll')
def ShowGameInviteUIForUser(user: win32more.Windows.Win32.System.WinRT.IInspectable, serviceConfigurationId: win32more.Windows.Win32.System.WinRT.HSTRING, sessionTemplateName: win32more.Windows.Win32.System.WinRT.HSTRING, sessionId: win32more.Windows.Win32.System.WinRT.HSTRING, invitationDisplayText: win32more.Windows.Win32.System.WinRT.HSTRING, completionRoutine: win32more.Windows.Win32.Gaming.GameUICompletionRoutine, context: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('api-ms-win-gaming-tcui-l1-1-2.dll')
def ShowPlayerPickerUIForUser(user: win32more.Windows.Win32.System.WinRT.IInspectable, promptDisplayText: win32more.Windows.Win32.System.WinRT.HSTRING, xuids: POINTER(win32more.Windows.Win32.System.WinRT.HSTRING), xuidsCount: UIntPtr, preSelectedXuids: POINTER(win32more.Windows.Win32.System.WinRT.HSTRING), preSelectedXuidsCount: UIntPtr, minSelectionCount: UIntPtr, maxSelectionCount: UIntPtr, completionRoutine: win32more.Windows.Win32.Gaming.PlayerPickerUICompletionRoutine, context: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('api-ms-win-gaming-tcui-l1-1-2.dll')
def ShowProfileCardUIForUser(user: win32more.Windows.Win32.System.WinRT.IInspectable, targetUserXuid: win32more.Windows.Win32.System.WinRT.HSTRING, completionRoutine: win32more.Windows.Win32.Gaming.GameUICompletionRoutine, context: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('api-ms-win-gaming-tcui-l1-1-2.dll')
def ShowChangeFriendRelationshipUIForUser(user: win32more.Windows.Win32.System.WinRT.IInspectable, targetUserXuid: win32more.Windows.Win32.System.WinRT.HSTRING, completionRoutine: win32more.Windows.Win32.Gaming.GameUICompletionRoutine, context: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('api-ms-win-gaming-tcui-l1-1-2.dll')
def ShowTitleAchievementsUIForUser(user: win32more.Windows.Win32.System.WinRT.IInspectable, titleId: UInt32, completionRoutine: win32more.Windows.Win32.Gaming.GameUICompletionRoutine, context: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('api-ms-win-gaming-tcui-l1-1-2.dll')
def CheckGamingPrivilegeWithUIForUser(user: win32more.Windows.Win32.System.WinRT.IInspectable, privilegeId: UInt32, scope: win32more.Windows.Win32.System.WinRT.HSTRING, policy: win32more.Windows.Win32.System.WinRT.HSTRING, friendlyMessage: win32more.Windows.Win32.System.WinRT.HSTRING, completionRoutine: win32more.Windows.Win32.Gaming.GameUICompletionRoutine, context: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('api-ms-win-gaming-tcui-l1-1-2.dll')
def CheckGamingPrivilegeSilentlyForUser(user: win32more.Windows.Win32.System.WinRT.IInspectable, privilegeId: UInt32, scope: win32more.Windows.Win32.System.WinRT.HSTRING, policy: win32more.Windows.Win32.System.WinRT.HSTRING, hasPrivilege: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('api-ms-win-gaming-tcui-l1-1-3.dll')
def ShowGameInviteUIWithContext(serviceConfigurationId: win32more.Windows.Win32.System.WinRT.HSTRING, sessionTemplateName: win32more.Windows.Win32.System.WinRT.HSTRING, sessionId: win32more.Windows.Win32.System.WinRT.HSTRING, invitationDisplayText: win32more.Windows.Win32.System.WinRT.HSTRING, customActivationContext: win32more.Windows.Win32.System.WinRT.HSTRING, completionRoutine: win32more.Windows.Win32.Gaming.GameUICompletionRoutine, context: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('api-ms-win-gaming-tcui-l1-1-3.dll')
def ShowGameInviteUIWithContextForUser(user: win32more.Windows.Win32.System.WinRT.IInspectable, serviceConfigurationId: win32more.Windows.Win32.System.WinRT.HSTRING, sessionTemplateName: win32more.Windows.Win32.System.WinRT.HSTRING, sessionId: win32more.Windows.Win32.System.WinRT.HSTRING, invitationDisplayText: win32more.Windows.Win32.System.WinRT.HSTRING, customActivationContext: win32more.Windows.Win32.System.WinRT.HSTRING, completionRoutine: win32more.Windows.Win32.Gaming.GameUICompletionRoutine, context: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('api-ms-win-gaming-tcui-l1-1-4.dll')
def ShowGameInfoUI(titleId: UInt32, completionRoutine: win32more.Windows.Win32.Gaming.GameUICompletionRoutine, context: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('api-ms-win-gaming-tcui-l1-1-4.dll')
def ShowGameInfoUIForUser(user: win32more.Windows.Win32.System.WinRT.IInspectable, titleId: UInt32, completionRoutine: win32more.Windows.Win32.Gaming.GameUICompletionRoutine, context: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('api-ms-win-gaming-tcui-l1-1-4.dll')
def ShowFindFriendsUI(completionRoutine: win32more.Windows.Win32.Gaming.GameUICompletionRoutine, context: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('api-ms-win-gaming-tcui-l1-1-4.dll')
def ShowFindFriendsUIForUser(user: win32more.Windows.Win32.System.WinRT.IInspectable, completionRoutine: win32more.Windows.Win32.Gaming.GameUICompletionRoutine, context: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('api-ms-win-gaming-tcui-l1-1-4.dll')
def ShowCustomizeUserProfileUI(completionRoutine: win32more.Windows.Win32.Gaming.GameUICompletionRoutine, context: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('api-ms-win-gaming-tcui-l1-1-4.dll')
def ShowCustomizeUserProfileUIForUser(user: win32more.Windows.Win32.System.WinRT.IInspectable, completionRoutine: win32more.Windows.Win32.Gaming.GameUICompletionRoutine, context: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('api-ms-win-gaming-tcui-l1-1-4.dll')
def ShowUserSettingsUI(completionRoutine: win32more.Windows.Win32.Gaming.GameUICompletionRoutine, context: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('api-ms-win-gaming-tcui-l1-1-4.dll')
def ShowUserSettingsUIForUser(user: win32more.Windows.Win32.System.WinRT.IInspectable, completionRoutine: win32more.Windows.Win32.Gaming.GameUICompletionRoutine, context: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
GAMESTATS_OPEN_RESULT = Int32
GAMESTATS_OPEN_CREATED: win32more.Windows.Win32.Gaming.GAMESTATS_OPEN_RESULT = 0
GAMESTATS_OPEN_OPENED: win32more.Windows.Win32.Gaming.GAMESTATS_OPEN_RESULT = 1
GAMESTATS_OPEN_TYPE = Int32
GAMESTATS_OPEN_OPENORCREATE: win32more.Windows.Win32.Gaming.GAMESTATS_OPEN_TYPE = 0
GAMESTATS_OPEN_OPENONLY: win32more.Windows.Win32.Gaming.GAMESTATS_OPEN_TYPE = 1
GAME_INSTALL_SCOPE = Int32
GIS_NOT_INSTALLED: win32more.Windows.Win32.Gaming.GAME_INSTALL_SCOPE = 1
GIS_CURRENT_USER: win32more.Windows.Win32.Gaming.GAME_INSTALL_SCOPE = 2
GIS_ALL_USERS: win32more.Windows.Win32.Gaming.GAME_INSTALL_SCOPE = 3
GAMING_DEVICE_DEVICE_ID = Int32
GAMING_DEVICE_DEVICE_ID_NONE: win32more.Windows.Win32.Gaming.GAMING_DEVICE_DEVICE_ID = 0
GAMING_DEVICE_DEVICE_ID_XBOX_ONE: win32more.Windows.Win32.Gaming.GAMING_DEVICE_DEVICE_ID = 1988865574
GAMING_DEVICE_DEVICE_ID_XBOX_ONE_S: win32more.Windows.Win32.Gaming.GAMING_DEVICE_DEVICE_ID = 712204761
GAMING_DEVICE_DEVICE_ID_XBOX_ONE_X: win32more.Windows.Win32.Gaming.GAMING_DEVICE_DEVICE_ID = 1523980231
GAMING_DEVICE_DEVICE_ID_XBOX_ONE_X_DEVKIT: win32more.Windows.Win32.Gaming.GAMING_DEVICE_DEVICE_ID = 284675555
GAMING_DEVICE_DEVICE_ID_XBOX_SERIES_S: win32more.Windows.Win32.Gaming.GAMING_DEVICE_DEVICE_ID = 489159355
GAMING_DEVICE_DEVICE_ID_XBOX_SERIES_X: win32more.Windows.Win32.Gaming.GAMING_DEVICE_DEVICE_ID = 796540415
GAMING_DEVICE_DEVICE_ID_XBOX_SERIES_X_DEVKIT: win32more.Windows.Win32.Gaming.GAMING_DEVICE_DEVICE_ID = -561359263
class GAMING_DEVICE_MODEL_INFORMATION(Structure):
    vendorId: win32more.Windows.Win32.Gaming.GAMING_DEVICE_VENDOR_ID
    deviceId: win32more.Windows.Win32.Gaming.GAMING_DEVICE_DEVICE_ID
GAMING_DEVICE_VENDOR_ID = Int32
GAMING_DEVICE_VENDOR_ID_NONE: win32more.Windows.Win32.Gaming.GAMING_DEVICE_VENDOR_ID = 0
GAMING_DEVICE_VENDOR_ID_MICROSOFT: win32more.Windows.Win32.Gaming.GAMING_DEVICE_VENDOR_ID = -1024700366
GameExplorer = Guid('{9a5ea990-3034-4d6f-9128-01f3c61022bc}')
GameStatistics = Guid('{dbc85a2c-c0dc-4961-b6e2-d28b62c11ad4}')
@winfunctype_pointer
def GameUICompletionRoutine(returnCode: win32more.Windows.Win32.Foundation.HRESULT, context: VoidPtr) -> Void: ...
class IGameExplorer(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{e7b2fb72-d728-49b3-a5f2-18ebf5f1349e}')
    @commethod(3)
    def AddGame(self, bstrGDFBinaryPath: win32more.Windows.Win32.Foundation.BSTR, bstrGameInstallDirectory: win32more.Windows.Win32.Foundation.BSTR, installScope: win32more.Windows.Win32.Gaming.GAME_INSTALL_SCOPE, pguidInstanceID: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def RemoveGame(self, guidInstanceID: Guid) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def UpdateGame(self, guidInstanceID: Guid) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def VerifyAccess(self, bstrGDFBinaryPath: win32more.Windows.Win32.Foundation.BSTR, pfHasAccess: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IGameExplorer2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{86874aa7-a1ed-450d-a7eb-b89e20b2fff3}')
    @commethod(3)
    def InstallGame(self, binaryGDFPath: win32more.Windows.Win32.Foundation.PWSTR, installDirectory: win32more.Windows.Win32.Foundation.PWSTR, installScope: win32more.Windows.Win32.Gaming.GAME_INSTALL_SCOPE) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def UninstallGame(self, binaryGDFPath: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def CheckAccess(self, binaryGDFPath: win32more.Windows.Win32.Foundation.PWSTR, pHasAccess: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IGameStatistics(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{3887c9ca-04a0-42ae-bc4c-5fa6c7721145}')
    @commethod(3)
    def GetMaxCategoryLength(self, cch: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetMaxNameLength(self, cch: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetMaxValueLength(self, cch: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetMaxCategories(self, pMax: POINTER(UInt16)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetMaxStatsPerCategory(self, pMax: POINTER(UInt16)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def SetCategoryTitle(self, categoryIndex: UInt16, title: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetCategoryTitle(self, categoryIndex: UInt16, pTitle: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GetStatistic(self, categoryIndex: UInt16, statIndex: UInt16, pName: POINTER(win32more.Windows.Win32.Foundation.PWSTR), pValue: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def SetStatistic(self, categoryIndex: UInt16, statIndex: UInt16, name: win32more.Windows.Win32.Foundation.PWSTR, value: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def Save(self, trackChanges: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def SetLastPlayedCategory(self, categoryIndex: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def GetLastPlayedCategory(self, pCategoryIndex: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IGameStatisticsMgr(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{aff3ea11-e70e-407d-95dd-35e612c41ce2}')
    @commethod(3)
    def GetGameStatistics(self, GDFBinaryPath: win32more.Windows.Win32.Foundation.PWSTR, openType: win32more.Windows.Win32.Gaming.GAMESTATS_OPEN_TYPE, pOpenResult: POINTER(win32more.Windows.Win32.Gaming.GAMESTATS_OPEN_RESULT), ppiStats: POINTER(win32more.Windows.Win32.Gaming.IGameStatistics)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def RemoveGameStatistics(self, GDFBinaryPath: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IXblIdpAuthManager(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{eb5ddb08-8bbf-449b-ac21-b02ddeb3b136}')
    @commethod(3)
    def SetGamerAccount(self, msaAccountId: win32more.Windows.Win32.Foundation.PWSTR, xuid: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetGamerAccount(self, msaAccountId: POINTER(win32more.Windows.Win32.Foundation.PWSTR), xuid: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SetAppViewInitialized(self, appSid: win32more.Windows.Win32.Foundation.PWSTR, msaAccountId: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetEnvironment(self, environment: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetSandbox(self, sandbox: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def GetTokenAndSignatureWithTokenResult(self, msaAccountId: win32more.Windows.Win32.Foundation.PWSTR, appSid: win32more.Windows.Win32.Foundation.PWSTR, msaTarget: win32more.Windows.Win32.Foundation.PWSTR, msaPolicy: win32more.Windows.Win32.Foundation.PWSTR, httpMethod: win32more.Windows.Win32.Foundation.PWSTR, uri: win32more.Windows.Win32.Foundation.PWSTR, headers: win32more.Windows.Win32.Foundation.PWSTR, body: POINTER(Byte), bodySize: UInt32, forceRefresh: win32more.Windows.Win32.Foundation.BOOL, result: POINTER(win32more.Windows.Win32.Gaming.IXblIdpAuthTokenResult)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IXblIdpAuthManager2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{bf8c0950-8389-43dd-9a76-a19728ec5dc5}')
    @commethod(3)
    def GetUserlessTokenAndSignatureWithTokenResult(self, appSid: win32more.Windows.Win32.Foundation.PWSTR, msaTarget: win32more.Windows.Win32.Foundation.PWSTR, msaPolicy: win32more.Windows.Win32.Foundation.PWSTR, httpMethod: win32more.Windows.Win32.Foundation.PWSTR, uri: win32more.Windows.Win32.Foundation.PWSTR, headers: win32more.Windows.Win32.Foundation.PWSTR, body: POINTER(Byte), bodySize: UInt32, forceRefresh: win32more.Windows.Win32.Foundation.BOOL, result: POINTER(win32more.Windows.Win32.Gaming.IXblIdpAuthTokenResult)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IXblIdpAuthTokenResult(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{46ce0225-f267-4d68-b299-b2762552dec1}')
    @commethod(3)
    def GetStatus(self, status: POINTER(win32more.Windows.Win32.Gaming.XBL_IDP_AUTH_TOKEN_STATUS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetErrorCode(self, errorCode: POINTER(win32more.Windows.Win32.Foundation.HRESULT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetToken(self, token: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetSignature(self, signature: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetSandbox(self, sandbox: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def GetEnvironment(self, environment: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetMsaAccountId(self, msaAccountId: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GetXuid(self, xuid: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def GetGamertag(self, gamertag: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def GetAgeGroup(self, ageGroup: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def GetPrivileges(self, privileges: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def GetMsaTarget(self, msaTarget: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def GetMsaPolicy(self, msaPolicy: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def GetMsaAppId(self, msaAppId: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def GetRedirect(self, redirect: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def GetMessage(self, message: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def GetHelpId(self, helpId: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def GetEnforcementBans(self, enforcementBans: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def GetRestrictions(self, restrictions: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def GetTitleRestrictions(self, titleRestrictions: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IXblIdpAuthTokenResult2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{75d760b0-60b9-412d-994f-26b2cd5f7812}')
    @commethod(3)
    def GetModernGamertag(self, value: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetModernGamertagSuffix(self, value: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetUniqueModernGamertag(self, value: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
KnownGamingPrivileges = Int32
XPRIVILEGE_BROADCAST: win32more.Windows.Win32.Gaming.KnownGamingPrivileges = 190
XPRIVILEGE_VIEW_FRIENDS_LIST: win32more.Windows.Win32.Gaming.KnownGamingPrivileges = 197
XPRIVILEGE_GAME_DVR: win32more.Windows.Win32.Gaming.KnownGamingPrivileges = 198
XPRIVILEGE_SHARE_KINECT_CONTENT: win32more.Windows.Win32.Gaming.KnownGamingPrivileges = 199
XPRIVILEGE_MULTIPLAYER_PARTIES: win32more.Windows.Win32.Gaming.KnownGamingPrivileges = 203
XPRIVILEGE_COMMUNICATION_VOICE_INGAME: win32more.Windows.Win32.Gaming.KnownGamingPrivileges = 205
XPRIVILEGE_COMMUNICATION_VOICE_SKYPE: win32more.Windows.Win32.Gaming.KnownGamingPrivileges = 206
XPRIVILEGE_CLOUD_GAMING_MANAGE_SESSION: win32more.Windows.Win32.Gaming.KnownGamingPrivileges = 207
XPRIVILEGE_CLOUD_GAMING_JOIN_SESSION: win32more.Windows.Win32.Gaming.KnownGamingPrivileges = 208
XPRIVILEGE_CLOUD_SAVED_GAMES: win32more.Windows.Win32.Gaming.KnownGamingPrivileges = 209
XPRIVILEGE_SHARE_CONTENT: win32more.Windows.Win32.Gaming.KnownGamingPrivileges = 211
XPRIVILEGE_PREMIUM_CONTENT: win32more.Windows.Win32.Gaming.KnownGamingPrivileges = 214
XPRIVILEGE_SUBSCRIPTION_CONTENT: win32more.Windows.Win32.Gaming.KnownGamingPrivileges = 219
XPRIVILEGE_SOCIAL_NETWORK_SHARING: win32more.Windows.Win32.Gaming.KnownGamingPrivileges = 220
XPRIVILEGE_PREMIUM_VIDEO: win32more.Windows.Win32.Gaming.KnownGamingPrivileges = 224
XPRIVILEGE_VIDEO_COMMUNICATIONS: win32more.Windows.Win32.Gaming.KnownGamingPrivileges = 235
XPRIVILEGE_PURCHASE_CONTENT: win32more.Windows.Win32.Gaming.KnownGamingPrivileges = 245
XPRIVILEGE_USER_CREATED_CONTENT: win32more.Windows.Win32.Gaming.KnownGamingPrivileges = 247
XPRIVILEGE_PROFILE_VIEWING: win32more.Windows.Win32.Gaming.KnownGamingPrivileges = 249
XPRIVILEGE_COMMUNICATIONS: win32more.Windows.Win32.Gaming.KnownGamingPrivileges = 252
XPRIVILEGE_MULTIPLAYER_SESSIONS: win32more.Windows.Win32.Gaming.KnownGamingPrivileges = 254
XPRIVILEGE_ADD_FRIEND: win32more.Windows.Win32.Gaming.KnownGamingPrivileges = 255
@winfunctype_pointer
def PlayerPickerUICompletionRoutine(returnCode: win32more.Windows.Win32.Foundation.HRESULT, context: VoidPtr, selectedXuids: POINTER(win32more.Windows.Win32.System.WinRT.HSTRING), selectedXuidsCount: UIntPtr) -> Void: ...
XBL_IDP_AUTH_TOKEN_STATUS = Int32
XBL_IDP_AUTH_TOKEN_STATUS_SUCCESS: win32more.Windows.Win32.Gaming.XBL_IDP_AUTH_TOKEN_STATUS = 0
XBL_IDP_AUTH_TOKEN_STATUS_OFFLINE_SUCCESS: win32more.Windows.Win32.Gaming.XBL_IDP_AUTH_TOKEN_STATUS = 1
XBL_IDP_AUTH_TOKEN_STATUS_NO_ACCOUNT_SET: win32more.Windows.Win32.Gaming.XBL_IDP_AUTH_TOKEN_STATUS = 2
XBL_IDP_AUTH_TOKEN_STATUS_LOAD_MSA_ACCOUNT_FAILED: win32more.Windows.Win32.Gaming.XBL_IDP_AUTH_TOKEN_STATUS = 3
XBL_IDP_AUTH_TOKEN_STATUS_XBOX_VETO: win32more.Windows.Win32.Gaming.XBL_IDP_AUTH_TOKEN_STATUS = 4
XBL_IDP_AUTH_TOKEN_STATUS_MSA_INTERRUPT: win32more.Windows.Win32.Gaming.XBL_IDP_AUTH_TOKEN_STATUS = 5
XBL_IDP_AUTH_TOKEN_STATUS_OFFLINE_NO_CONSENT: win32more.Windows.Win32.Gaming.XBL_IDP_AUTH_TOKEN_STATUS = 6
XBL_IDP_AUTH_TOKEN_STATUS_VIEW_NOT_SET: win32more.Windows.Win32.Gaming.XBL_IDP_AUTH_TOKEN_STATUS = 7
XBL_IDP_AUTH_TOKEN_STATUS_UNKNOWN: win32more.Windows.Win32.Gaming.XBL_IDP_AUTH_TOKEN_STATUS = -1
XblIdpAuthManager = Guid('{ce23534b-56d8-4978-86a2-7ee570640468}')
XblIdpAuthTokenResult = Guid('{9f493441-744a-410c-ae2b-9a22f7c7731f}')


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.Foundation
import win32more.Windows.Phone.UI.Input
import win32more.Windows.Win32.System.WinRT
class BackPressedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Phone.UI.Input.IBackPressedEventArgs
    _classid_ = 'Windows.Phone.UI.Input.BackPressedEventArgs'
    @winrt_mixinmethod
    def get_Handled(self: win32more.Windows.Phone.UI.Input.IBackPressedEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def put_Handled(self: win32more.Windows.Phone.UI.Input.IBackPressedEventArgs, value: Boolean) -> Void: ...
    Handled = property(get_Handled, put_Handled)
class CameraEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Phone.UI.Input.ICameraEventArgs
    _classid_ = 'Windows.Phone.UI.Input.CameraEventArgs'
class HardwareButtons(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Phone.UI.Input.HardwareButtons'
    @winrt_classmethod
    def add_BackPressed(cls: win32more.Windows.Phone.UI.Input.IHardwareButtonsStatics, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.Phone.UI.Input.BackPressedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_classmethod
    def remove_BackPressed(cls: win32more.Windows.Phone.UI.Input.IHardwareButtonsStatics, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def add_CameraHalfPressed(cls: win32more.Windows.Phone.UI.Input.IHardwareButtonsStatics2, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.Phone.UI.Input.CameraEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_classmethod
    def remove_CameraHalfPressed(cls: win32more.Windows.Phone.UI.Input.IHardwareButtonsStatics2, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def add_CameraPressed(cls: win32more.Windows.Phone.UI.Input.IHardwareButtonsStatics2, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.Phone.UI.Input.CameraEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_classmethod
    def remove_CameraPressed(cls: win32more.Windows.Phone.UI.Input.IHardwareButtonsStatics2, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def add_CameraReleased(cls: win32more.Windows.Phone.UI.Input.IHardwareButtonsStatics2, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.Phone.UI.Input.CameraEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_classmethod
    def remove_CameraReleased(cls: win32more.Windows.Phone.UI.Input.IHardwareButtonsStatics2, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
class IBackPressedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Phone.UI.Input.IBackPressedEventArgs'
    _iid_ = Guid('{f6f555ff-64ec-42a2-b93b-2fbc0c36a121}')
    @winrt_commethod(6)
    def get_Handled(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_Handled(self, value: Boolean) -> Void: ...
    Handled = property(get_Handled, put_Handled)
class ICameraEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Phone.UI.Input.ICameraEventArgs'
    _iid_ = Guid('{b4063bda-201f-473d-bc69-e9e4ac57c9d0}')
class IHardwareButtonsStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Phone.UI.Input.IHardwareButtonsStatics'
    _iid_ = Guid('{594b8780-da66-4fd8-a776-7506bd0cbfa7}')
    @winrt_commethod(6)
    def add_BackPressed(self, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.Phone.UI.Input.BackPressedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(7)
    def remove_BackPressed(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    BackPressed = event()
class IHardwareButtonsStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Phone.UI.Input.IHardwareButtonsStatics2'
    _iid_ = Guid('{39c6c274-993f-40dd-854c-831a8934b92e}')
    @winrt_commethod(6)
    def add_CameraHalfPressed(self, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.Phone.UI.Input.CameraEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(7)
    def remove_CameraHalfPressed(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(8)
    def add_CameraPressed(self, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.Phone.UI.Input.CameraEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(9)
    def remove_CameraPressed(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(10)
    def add_CameraReleased(self, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.Phone.UI.Input.CameraEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(11)
    def remove_CameraReleased(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    CameraHalfPressed = event()
    CameraPressed = event()
    CameraReleased = event()


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.Foundation
import win32more.Windows.Security.DataProtection
import win32more.Windows.Storage
import win32more.Windows.Storage.Streams
import win32more.Windows.System
import win32more.Windows.Win32.System.WinRT
class IUserDataAvailabilityStateChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Security.DataProtection.IUserDataAvailabilityStateChangedEventArgs'
    _iid_ = Guid('{a76582c9-06a2-4273-a803-834c9f87fbeb}')
    @winrt_commethod(6)
    def GetDeferral(self) -> win32more.Windows.Foundation.Deferral: ...
class IUserDataBufferUnprotectResult(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Security.DataProtection.IUserDataBufferUnprotectResult'
    _iid_ = Guid('{8efd0e90-fa9a-46a4-a377-01cebf1e74d8}')
    @winrt_commethod(6)
    def get_Status(self) -> win32more.Windows.Security.DataProtection.UserDataBufferUnprotectStatus: ...
    @winrt_commethod(7)
    def get_UnprotectedBuffer(self) -> win32more.Windows.Storage.Streams.IBuffer: ...
    Status = property(get_Status, None)
    UnprotectedBuffer = property(get_UnprotectedBuffer, None)
class IUserDataProtectionManager(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Security.DataProtection.IUserDataProtectionManager'
    _iid_ = Guid('{1f13237d-b42e-4a88-9480-0f240924c876}')
    @winrt_commethod(6)
    def ProtectStorageItemAsync(self, storageItem: win32more.Windows.Storage.IStorageItem, availability: win32more.Windows.Security.DataProtection.UserDataAvailability) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Security.DataProtection.UserDataStorageItemProtectionStatus]: ...
    @winrt_commethod(7)
    def GetStorageItemProtectionInfoAsync(self, storageItem: win32more.Windows.Storage.IStorageItem) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Security.DataProtection.UserDataStorageItemProtectionInfo]: ...
    @winrt_commethod(8)
    def ProtectBufferAsync(self, unprotectedBuffer: win32more.Windows.Storage.Streams.IBuffer, availability: win32more.Windows.Security.DataProtection.UserDataAvailability) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.Streams.IBuffer]: ...
    @winrt_commethod(9)
    def UnprotectBufferAsync(self, protectedBuffer: win32more.Windows.Storage.Streams.IBuffer) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Security.DataProtection.UserDataBufferUnprotectResult]: ...
    @winrt_commethod(10)
    def IsContinuedDataAvailabilityExpected(self, availability: win32more.Windows.Security.DataProtection.UserDataAvailability) -> Boolean: ...
    @winrt_commethod(11)
    def add_DataAvailabilityStateChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Security.DataProtection.UserDataProtectionManager, win32more.Windows.Security.DataProtection.UserDataAvailabilityStateChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(12)
    def remove_DataAvailabilityStateChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    DataAvailabilityStateChanged = event()
class IUserDataProtectionManagerStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Security.DataProtection.IUserDataProtectionManagerStatics'
    _iid_ = Guid('{977780e8-6dce-4fae-af85-782ac2cf4572}')
    @winrt_commethod(6)
    def TryGetDefault(self) -> win32more.Windows.Security.DataProtection.UserDataProtectionManager: ...
    @winrt_commethod(7)
    def TryGetForUser(self, user: win32more.Windows.System.User) -> win32more.Windows.Security.DataProtection.UserDataProtectionManager: ...
class IUserDataStorageItemProtectionInfo(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Security.DataProtection.IUserDataStorageItemProtectionInfo'
    _iid_ = Guid('{5b6680f6-e87f-40a1-b19d-a6187a0c662f}')
    @winrt_commethod(6)
    def get_Availability(self) -> win32more.Windows.Security.DataProtection.UserDataAvailability: ...
    Availability = property(get_Availability, None)
class UserDataAvailability(Enum, Int32):
    Always = 0
    AfterFirstUnlock = 1
    WhileUnlocked = 2
class UserDataAvailabilityStateChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Security.DataProtection.IUserDataAvailabilityStateChangedEventArgs
    _classid_ = 'Windows.Security.DataProtection.UserDataAvailabilityStateChangedEventArgs'
    @winrt_mixinmethod
    def GetDeferral(self: win32more.Windows.Security.DataProtection.IUserDataAvailabilityStateChangedEventArgs) -> win32more.Windows.Foundation.Deferral: ...
class UserDataBufferUnprotectResult(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Security.DataProtection.IUserDataBufferUnprotectResult
    _classid_ = 'Windows.Security.DataProtection.UserDataBufferUnprotectResult'
    @winrt_mixinmethod
    def get_Status(self: win32more.Windows.Security.DataProtection.IUserDataBufferUnprotectResult) -> win32more.Windows.Security.DataProtection.UserDataBufferUnprotectStatus: ...
    @winrt_mixinmethod
    def get_UnprotectedBuffer(self: win32more.Windows.Security.DataProtection.IUserDataBufferUnprotectResult) -> win32more.Windows.Storage.Streams.IBuffer: ...
    Status = property(get_Status, None)
    UnprotectedBuffer = property(get_UnprotectedBuffer, None)
class UserDataBufferUnprotectStatus(Enum, Int32):
    Succeeded = 0
    Unavailable = 1
class UserDataProtectionManager(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Security.DataProtection.IUserDataProtectionManager
    _classid_ = 'Windows.Security.DataProtection.UserDataProtectionManager'
    @winrt_mixinmethod
    def ProtectStorageItemAsync(self: win32more.Windows.Security.DataProtection.IUserDataProtectionManager, storageItem: win32more.Windows.Storage.IStorageItem, availability: win32more.Windows.Security.DataProtection.UserDataAvailability) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Security.DataProtection.UserDataStorageItemProtectionStatus]: ...
    @winrt_mixinmethod
    def GetStorageItemProtectionInfoAsync(self: win32more.Windows.Security.DataProtection.IUserDataProtectionManager, storageItem: win32more.Windows.Storage.IStorageItem) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Security.DataProtection.UserDataStorageItemProtectionInfo]: ...
    @winrt_mixinmethod
    def ProtectBufferAsync(self: win32more.Windows.Security.DataProtection.IUserDataProtectionManager, unprotectedBuffer: win32more.Windows.Storage.Streams.IBuffer, availability: win32more.Windows.Security.DataProtection.UserDataAvailability) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.Streams.IBuffer]: ...
    @winrt_mixinmethod
    def UnprotectBufferAsync(self: win32more.Windows.Security.DataProtection.IUserDataProtectionManager, protectedBuffer: win32more.Windows.Storage.Streams.IBuffer) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Security.DataProtection.UserDataBufferUnprotectResult]: ...
    @winrt_mixinmethod
    def IsContinuedDataAvailabilityExpected(self: win32more.Windows.Security.DataProtection.IUserDataProtectionManager, availability: win32more.Windows.Security.DataProtection.UserDataAvailability) -> Boolean: ...
    @winrt_mixinmethod
    def add_DataAvailabilityStateChanged(self: win32more.Windows.Security.DataProtection.IUserDataProtectionManager, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Security.DataProtection.UserDataProtectionManager, win32more.Windows.Security.DataProtection.UserDataAvailabilityStateChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_DataAvailabilityStateChanged(self: win32more.Windows.Security.DataProtection.IUserDataProtectionManager, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def TryGetDefault(cls: win32more.Windows.Security.DataProtection.IUserDataProtectionManagerStatics) -> win32more.Windows.Security.DataProtection.UserDataProtectionManager: ...
    @winrt_classmethod
    def TryGetForUser(cls: win32more.Windows.Security.DataProtection.IUserDataProtectionManagerStatics, user: win32more.Windows.System.User) -> win32more.Windows.Security.DataProtection.UserDataProtectionManager: ...
    DataAvailabilityStateChanged = event()
class UserDataStorageItemProtectionInfo(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Security.DataProtection.IUserDataStorageItemProtectionInfo
    _classid_ = 'Windows.Security.DataProtection.UserDataStorageItemProtectionInfo'
    @winrt_mixinmethod
    def get_Availability(self: win32more.Windows.Security.DataProtection.IUserDataStorageItemProtectionInfo) -> win32more.Windows.Security.DataProtection.UserDataAvailability: ...
    Availability = property(get_Availability, None)
class UserDataStorageItemProtectionStatus(Enum, Int32):
    Succeeded = 0
    NotProtectable = 1
    DataUnavailable = 2


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.Media.ContentRestrictions
import win32more.Windows.Storage.Streams
import win32more.Windows.Win32.System.WinRT
class ContentAccessRestrictionLevel(Enum, Int32):
    Allow = 0
    Warn = 1
    Block = 2
    Hide = 3
class ContentRestrictionsBrowsePolicy(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.ContentRestrictions.IContentRestrictionsBrowsePolicy
    _classid_ = 'Windows.Media.ContentRestrictions.ContentRestrictionsBrowsePolicy'
    @winrt_mixinmethod
    def get_GeographicRegion(self: win32more.Windows.Media.ContentRestrictions.IContentRestrictionsBrowsePolicy) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_MaxBrowsableAgeRating(self: win32more.Windows.Media.ContentRestrictions.IContentRestrictionsBrowsePolicy) -> win32more.Windows.Foundation.IReference[UInt32]: ...
    @winrt_mixinmethod
    def get_PreferredAgeRating(self: win32more.Windows.Media.ContentRestrictions.IContentRestrictionsBrowsePolicy) -> win32more.Windows.Foundation.IReference[UInt32]: ...
    GeographicRegion = property(get_GeographicRegion, None)
    MaxBrowsableAgeRating = property(get_MaxBrowsableAgeRating, None)
    PreferredAgeRating = property(get_PreferredAgeRating, None)
class IContentRestrictionsBrowsePolicy(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.ContentRestrictions.IContentRestrictionsBrowsePolicy'
    _iid_ = Guid('{8c0133a4-442e-461a-8757-fad2f5bd37e4}')
    @winrt_commethod(6)
    def get_GeographicRegion(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_MaxBrowsableAgeRating(self) -> win32more.Windows.Foundation.IReference[UInt32]: ...
    @winrt_commethod(8)
    def get_PreferredAgeRating(self) -> win32more.Windows.Foundation.IReference[UInt32]: ...
    GeographicRegion = property(get_GeographicRegion, None)
    MaxBrowsableAgeRating = property(get_MaxBrowsableAgeRating, None)
    PreferredAgeRating = property(get_PreferredAgeRating, None)
class IRatedContentDescription(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.ContentRestrictions.IRatedContentDescription'
    _iid_ = Guid('{694866df-66b2-4dc3-96b1-f090eedee255}')
    @winrt_commethod(6)
    def get_Id(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def put_Id(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(8)
    def get_Title(self) -> WinRT_String: ...
    @winrt_commethod(9)
    def put_Title(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(10)
    def get_Image(self) -> win32more.Windows.Storage.Streams.IRandomAccessStreamReference: ...
    @winrt_commethod(11)
    def put_Image(self, value: win32more.Windows.Storage.Streams.IRandomAccessStreamReference) -> Void: ...
    @winrt_commethod(12)
    def get_Category(self) -> win32more.Windows.Media.ContentRestrictions.RatedContentCategory: ...
    @winrt_commethod(13)
    def put_Category(self, value: win32more.Windows.Media.ContentRestrictions.RatedContentCategory) -> Void: ...
    @winrt_commethod(14)
    def get_Ratings(self) -> win32more.Windows.Foundation.Collections.IVector[WinRT_String]: ...
    @winrt_commethod(15)
    def put_Ratings(self, value: win32more.Windows.Foundation.Collections.IVector[WinRT_String]) -> Void: ...
    Category = property(get_Category, put_Category)
    Id = property(get_Id, put_Id)
    Image = property(get_Image, put_Image)
    Ratings = property(get_Ratings, put_Ratings)
    Title = property(get_Title, put_Title)
class IRatedContentDescriptionFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.ContentRestrictions.IRatedContentDescriptionFactory'
    _iid_ = Guid('{2e38df62-9b90-4fa6-89c1-4b8d2ffb3573}')
    @winrt_commethod(6)
    def Create(self, id: WinRT_String, title: WinRT_String, category: win32more.Windows.Media.ContentRestrictions.RatedContentCategory) -> win32more.Windows.Media.ContentRestrictions.RatedContentDescription: ...
class IRatedContentRestrictions(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.ContentRestrictions.IRatedContentRestrictions'
    _iid_ = Guid('{3f7f23cb-ba07-4401-a49d-8b9222205723}')
    @winrt_commethod(6)
    def GetBrowsePolicyAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Media.ContentRestrictions.ContentRestrictionsBrowsePolicy]: ...
    @winrt_commethod(7)
    def GetRestrictionLevelAsync(self, RatedContentDescription: win32more.Windows.Media.ContentRestrictions.RatedContentDescription) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Media.ContentRestrictions.ContentAccessRestrictionLevel]: ...
    @winrt_commethod(8)
    def RequestContentAccessAsync(self, RatedContentDescription: win32more.Windows.Media.ContentRestrictions.RatedContentDescription) -> win32more.Windows.Foundation.IAsyncOperation[Boolean]: ...
    @winrt_commethod(9)
    def add_RestrictionsChanged(self, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(10)
    def remove_RestrictionsChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    RestrictionsChanged = event()
class IRatedContentRestrictionsFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.ContentRestrictions.IRatedContentRestrictionsFactory'
    _iid_ = Guid('{fb4b2996-c3bd-4910-9619-97cfd0694d56}')
    @winrt_commethod(6)
    def CreateWithMaxAgeRating(self, maxAgeRating: UInt32) -> win32more.Windows.Media.ContentRestrictions.RatedContentRestrictions: ...
class RatedContentCategory(Enum, Int32):
    General = 0
    Application = 1
    Game = 2
    Movie = 3
    Television = 4
    Music = 5
class RatedContentDescription(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.ContentRestrictions.IRatedContentDescription
    _classid_ = 'Windows.Media.ContentRestrictions.RatedContentDescription'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 3:
            super().__init__(move=win32more.Windows.Media.ContentRestrictions.RatedContentDescription.Create(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def Create(cls: win32more.Windows.Media.ContentRestrictions.IRatedContentDescriptionFactory, id: WinRT_String, title: WinRT_String, category: win32more.Windows.Media.ContentRestrictions.RatedContentCategory) -> win32more.Windows.Media.ContentRestrictions.RatedContentDescription: ...
    @winrt_mixinmethod
    def get_Id(self: win32more.Windows.Media.ContentRestrictions.IRatedContentDescription) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Id(self: win32more.Windows.Media.ContentRestrictions.IRatedContentDescription, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Title(self: win32more.Windows.Media.ContentRestrictions.IRatedContentDescription) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Title(self: win32more.Windows.Media.ContentRestrictions.IRatedContentDescription, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Image(self: win32more.Windows.Media.ContentRestrictions.IRatedContentDescription) -> win32more.Windows.Storage.Streams.IRandomAccessStreamReference: ...
    @winrt_mixinmethod
    def put_Image(self: win32more.Windows.Media.ContentRestrictions.IRatedContentDescription, value: win32more.Windows.Storage.Streams.IRandomAccessStreamReference) -> Void: ...
    @winrt_mixinmethod
    def get_Category(self: win32more.Windows.Media.ContentRestrictions.IRatedContentDescription) -> win32more.Windows.Media.ContentRestrictions.RatedContentCategory: ...
    @winrt_mixinmethod
    def put_Category(self: win32more.Windows.Media.ContentRestrictions.IRatedContentDescription, value: win32more.Windows.Media.ContentRestrictions.RatedContentCategory) -> Void: ...
    @winrt_mixinmethod
    def get_Ratings(self: win32more.Windows.Media.ContentRestrictions.IRatedContentDescription) -> win32more.Windows.Foundation.Collections.IVector[WinRT_String]: ...
    @winrt_mixinmethod
    def put_Ratings(self: win32more.Windows.Media.ContentRestrictions.IRatedContentDescription, value: win32more.Windows.Foundation.Collections.IVector[WinRT_String]) -> Void: ...
    Category = property(get_Category, put_Category)
    Id = property(get_Id, put_Id)
    Image = property(get_Image, put_Image)
    Ratings = property(get_Ratings, put_Ratings)
    Title = property(get_Title, put_Title)
class RatedContentRestrictions(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.ContentRestrictions.IRatedContentRestrictions
    _classid_ = 'Windows.Media.ContentRestrictions.RatedContentRestrictions'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.Media.ContentRestrictions.RatedContentRestrictions.CreateInstance(*args))
        elif len(args) == 1:
            super().__init__(move=win32more.Windows.Media.ContentRestrictions.RatedContentRestrictions.CreateWithMaxAgeRating(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.Media.ContentRestrictions.RatedContentRestrictions: ...
    @winrt_factorymethod
    def CreateWithMaxAgeRating(cls: win32more.Windows.Media.ContentRestrictions.IRatedContentRestrictionsFactory, maxAgeRating: UInt32) -> win32more.Windows.Media.ContentRestrictions.RatedContentRestrictions: ...
    @winrt_mixinmethod
    def GetBrowsePolicyAsync(self: win32more.Windows.Media.ContentRestrictions.IRatedContentRestrictions) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Media.ContentRestrictions.ContentRestrictionsBrowsePolicy]: ...
    @winrt_mixinmethod
    def GetRestrictionLevelAsync(self: win32more.Windows.Media.ContentRestrictions.IRatedContentRestrictions, RatedContentDescription: win32more.Windows.Media.ContentRestrictions.RatedContentDescription) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Media.ContentRestrictions.ContentAccessRestrictionLevel]: ...
    @winrt_mixinmethod
    def RequestContentAccessAsync(self: win32more.Windows.Media.ContentRestrictions.IRatedContentRestrictions, RatedContentDescription: win32more.Windows.Media.ContentRestrictions.RatedContentDescription) -> win32more.Windows.Foundation.IAsyncOperation[Boolean]: ...
    @winrt_mixinmethod
    def add_RestrictionsChanged(self: win32more.Windows.Media.ContentRestrictions.IRatedContentRestrictions, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_RestrictionsChanged(self: win32more.Windows.Media.ContentRestrictions.IRatedContentRestrictions, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    RestrictionsChanged = event()


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.Win32.System.Com
import win32more.Windows.Win32.System.WinRT
class CollectionChange(Enum, Int32):
    Reset = 0
    ItemInserted = 1
    ItemRemoved = 2
    ItemChanged = 3
class IIterable(Generic[T], ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[IterableProtocol[T]]
    _classid_ = 'Windows.Foundation.Collections.IIterable'
    _piid_ = Guid('{faa585ea-6214-4217-afda-7f46de5869b3}')
    @winrt_commethod(6)
    def First(self) -> win32more.Windows.Foundation.Collections.IIterator[T]: ...
class IIterator(Generic[T], ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Foundation.Collections.IIterator'
    _piid_ = Guid('{6a79e863-4300-459a-9966-cbb660963ee1}')
    @winrt_commethod(6)
    def get_Current(self) -> T: ...
    @winrt_commethod(7)
    def get_HasCurrent(self) -> Boolean: ...
    @winrt_commethod(8)
    def MoveNext(self) -> Boolean: ...
    @winrt_commethod(9)
    def GetMany(self, items: FillArray[T]) -> UInt32: ...
    Current = property(get_Current, None)
    HasCurrent = property(get_HasCurrent, None)
class IKeyValuePair(Generic[K, V], ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Foundation.Collections.IKeyValuePair'
    _piid_ = Guid('{02b51929-c1c4-4a7e-8940-0312b5c18500}')
    @winrt_commethod(6)
    def get_Key(self) -> K: ...
    @winrt_commethod(7)
    def get_Value(self) -> V: ...
    Key = property(get_Key, None)
    Value = property(get_Value, None)
class IMapChangedEventArgs(Generic[K], ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Foundation.Collections.IMapChangedEventArgs'
    _piid_ = Guid('{9939f4df-050a-4c0f-aa60-77075f9c4777}')
    @winrt_commethod(6)
    def get_CollectionChange(self) -> win32more.Windows.Foundation.Collections.CollectionChange: ...
    @winrt_commethod(7)
    def get_Key(self) -> K: ...
    CollectionChange = property(get_CollectionChange, None)
    Key = property(get_Key, None)
class IMapView(Generic[K, V], ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[MappingProtocol[K, V]]
    _classid_ = 'Windows.Foundation.Collections.IMapView'
    _piid_ = Guid('{e480ce40-a338-4ada-adcf-272272e48cb9}')
    @winrt_commethod(6)
    def Lookup(self, key: K) -> V: ...
    @winrt_commethod(7)
    def get_Size(self) -> UInt32: ...
    @winrt_commethod(8)
    def HasKey(self, key: K) -> Boolean: ...
    @winrt_commethod(9)
    def Split(self, first: POINTER(win32more.Windows.Foundation.Collections.IMapView[K, V]), second: POINTER(win32more.Windows.Foundation.Collections.IMapView[K, V])) -> Void: ...
    Size = property(get_Size, None)
class IMap(Generic[K, V], ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[MappingProtocol[K, V]]
    _classid_ = 'Windows.Foundation.Collections.IMap'
    _piid_ = Guid('{3c2925fe-8519-45c1-aa79-197b6718c1c1}')
    @winrt_commethod(6)
    def Lookup(self, key: K) -> V: ...
    @winrt_commethod(7)
    def get_Size(self) -> UInt32: ...
    @winrt_commethod(8)
    def HasKey(self, key: K) -> Boolean: ...
    @winrt_commethod(9)
    def GetView(self) -> win32more.Windows.Foundation.Collections.IMapView[K, V]: ...
    @winrt_commethod(10)
    def Insert(self, key: K, value: V) -> Boolean: ...
    @winrt_commethod(11)
    def Remove(self, key: K) -> Void: ...
    @winrt_commethod(12)
    def Clear(self) -> Void: ...
    Size = property(get_Size, None)
class IObservableMap(Generic[K, V], ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[MappingProtocol[K, V]]
    _classid_ = 'Windows.Foundation.Collections.IObservableMap'
    _piid_ = Guid('{65df2bf5-bf39-41b5-aebc-5a9d865e472b}')
    @winrt_commethod(6)
    def add_MapChanged(self, vhnd: win32more.Windows.Foundation.Collections.MapChangedEventHandler[K, V]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(7)
    def remove_MapChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    MapChanged = event()
class IObservableVector(Generic[T], ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[SequenceProtocol[T]]
    _classid_ = 'Windows.Foundation.Collections.IObservableVector'
    _piid_ = Guid('{5917eb53-50b4-4a0d-b309-65862b3f1dbc}')
    @winrt_commethod(6)
    def add_VectorChanged(self, vhnd: win32more.Windows.Foundation.Collections.VectorChangedEventHandler[T]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(7)
    def remove_VectorChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    VectorChanged = event()
class IPropertySet(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[MappingProtocol[WinRT_String, win32more.Windows.Win32.System.WinRT.IInspectable]]
    _classid_ = 'Windows.Foundation.Collections.IPropertySet'
    _iid_ = Guid('{8a43ed9f-f4e6-4421-acf9-1dab2986820c}')
class IVectorChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Foundation.Collections.IVectorChangedEventArgs'
    _iid_ = Guid('{575933df-34fe-4480-af15-07691f3d5d9b}')
    @winrt_commethod(6)
    def get_CollectionChange(self) -> win32more.Windows.Foundation.Collections.CollectionChange: ...
    @winrt_commethod(7)
    def get_Index(self) -> UInt32: ...
    CollectionChange = property(get_CollectionChange, None)
    Index = property(get_Index, None)
class IVectorView(Generic[T], ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[SequenceProtocol[T]]
    _classid_ = 'Windows.Foundation.Collections.IVectorView'
    _piid_ = Guid('{bbe1fa4c-b0e3-4583-baef-1f1b2e483e56}')
    @winrt_commethod(6)
    def GetAt(self, index: UInt32) -> T: ...
    @winrt_commethod(7)
    def get_Size(self) -> UInt32: ...
    @winrt_commethod(8)
    def IndexOf(self, value: T, index: POINTER(UInt32)) -> Boolean: ...
    @winrt_commethod(9)
    def GetMany(self, startIndex: UInt32, items: FillArray[T]) -> UInt32: ...
    Size = property(get_Size, None)
class IVector(Generic[T], ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[SequenceProtocol[T]]
    _classid_ = 'Windows.Foundation.Collections.IVector'
    _piid_ = Guid('{913337e9-11a1-4345-a3a2-4e7f956e222d}')
    @winrt_commethod(6)
    def GetAt(self, index: UInt32) -> T: ...
    @winrt_commethod(7)
    def get_Size(self) -> UInt32: ...
    @winrt_commethod(8)
    def GetView(self) -> win32more.Windows.Foundation.Collections.IVectorView[T]: ...
    @winrt_commethod(9)
    def IndexOf(self, value: T, index: POINTER(UInt32)) -> Boolean: ...
    @winrt_commethod(10)
    def SetAt(self, index: UInt32, value: T) -> Void: ...
    @winrt_commethod(11)
    def InsertAt(self, index: UInt32, value: T) -> Void: ...
    @winrt_commethod(12)
    def RemoveAt(self, index: UInt32) -> Void: ...
    @winrt_commethod(13)
    def Append(self, value: T) -> Void: ...
    @winrt_commethod(14)
    def RemoveAtEnd(self) -> Void: ...
    @winrt_commethod(15)
    def Clear(self) -> Void: ...
    @winrt_commethod(16)
    def GetMany(self, startIndex: UInt32, items: FillArray[T]) -> UInt32: ...
    @winrt_commethod(17)
    def ReplaceAll(self, items: PassArray[T]) -> Void: ...
    Size = property(get_Size, None)
class MapChangedEventHandler(Generic[K, V], MulticastDelegate):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _piid_ = Guid('{179517f3-94ee-41f8-bddc-768a895544f3}')
    @winrt_commethod(3)
    def Invoke(self, sender: win32more.Windows.Foundation.Collections.IObservableMap[K, V], event: win32more.Windows.Foundation.Collections.IMapChangedEventArgs[K]) -> Void: ...
class PropertySet(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[MappingProtocol[WinRT_String, win32more.Windows.Win32.System.WinRT.IInspectable]]
    default_interface: win32more.Windows.Foundation.Collections.IPropertySet
    _classid_ = 'Windows.Foundation.Collections.PropertySet'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.Foundation.Collections.PropertySet.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.Foundation.Collections.PropertySet: ...
    @winrt_mixinmethod
    def add_MapChanged(self: win32more.Windows.Foundation.Collections.IObservableMap[WinRT_String, win32more.Windows.Win32.System.WinRT.IInspectable], vhnd: win32more.Windows.Foundation.Collections.MapChangedEventHandler[WinRT_String, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_MapChanged(self: win32more.Windows.Foundation.Collections.IObservableMap[WinRT_String, win32more.Windows.Win32.System.WinRT.IInspectable], token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def Lookup(self: win32more.Windows.Foundation.Collections.IMap[WinRT_String, win32more.Windows.Win32.System.WinRT.IInspectable], key: WinRT_String) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def get_Size(self: win32more.Windows.Foundation.Collections.IMap[WinRT_String, win32more.Windows.Win32.System.WinRT.IInspectable]) -> UInt32: ...
    @winrt_mixinmethod
    def HasKey(self: win32more.Windows.Foundation.Collections.IMap[WinRT_String, win32more.Windows.Win32.System.WinRT.IInspectable], key: WinRT_String) -> Boolean: ...
    @winrt_mixinmethod
    def GetView(self: win32more.Windows.Foundation.Collections.IMap[WinRT_String, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.Collections.IMapView[WinRT_String, win32more.Windows.Win32.System.WinRT.IInspectable]: ...
    @winrt_mixinmethod
    def Insert(self: win32more.Windows.Foundation.Collections.IMap[WinRT_String, win32more.Windows.Win32.System.WinRT.IInspectable], key: WinRT_String, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Boolean: ...
    @winrt_mixinmethod
    def Remove(self: win32more.Windows.Foundation.Collections.IMap[WinRT_String, win32more.Windows.Win32.System.WinRT.IInspectable], key: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def Clear(self: win32more.Windows.Foundation.Collections.IMap[WinRT_String, win32more.Windows.Win32.System.WinRT.IInspectable]) -> Void: ...
    @winrt_mixinmethod
    def First(self: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.Foundation.Collections.IKeyValuePair[WinRT_String, win32more.Windows.Win32.System.WinRT.IInspectable]]) -> win32more.Windows.Foundation.Collections.IIterator[win32more.Windows.Foundation.Collections.IKeyValuePair[WinRT_String, win32more.Windows.Win32.System.WinRT.IInspectable]]: ...
    Size = property(get_Size, None)
    MapChanged = event()
class StringMap(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[MappingProtocol[WinRT_String, WinRT_String]]
    default_interface: win32more.Windows.Foundation.Collections.IMap[WinRT_String, WinRT_String]
    _classid_ = 'Windows.Foundation.Collections.StringMap'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.Foundation.Collections.StringMap.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.Foundation.Collections.StringMap: ...
    @winrt_mixinmethod
    def Lookup(self: win32more.Windows.Foundation.Collections.IMap[WinRT_String, WinRT_String], key: WinRT_String) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Size(self: win32more.Windows.Foundation.Collections.IMap[WinRT_String, WinRT_String]) -> UInt32: ...
    @winrt_mixinmethod
    def HasKey(self: win32more.Windows.Foundation.Collections.IMap[WinRT_String, WinRT_String], key: WinRT_String) -> Boolean: ...
    @winrt_mixinmethod
    def GetView(self: win32more.Windows.Foundation.Collections.IMap[WinRT_String, WinRT_String]) -> win32more.Windows.Foundation.Collections.IMapView[WinRT_String, WinRT_String]: ...
    @winrt_mixinmethod
    def Insert(self: win32more.Windows.Foundation.Collections.IMap[WinRT_String, WinRT_String], key: WinRT_String, value: WinRT_String) -> Boolean: ...
    @winrt_mixinmethod
    def Remove(self: win32more.Windows.Foundation.Collections.IMap[WinRT_String, WinRT_String], key: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def Clear(self: win32more.Windows.Foundation.Collections.IMap[WinRT_String, WinRT_String]) -> Void: ...
    @winrt_mixinmethod
    def First(self: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.Foundation.Collections.IKeyValuePair[WinRT_String, WinRT_String]]) -> win32more.Windows.Foundation.Collections.IIterator[win32more.Windows.Foundation.Collections.IKeyValuePair[WinRT_String, WinRT_String]]: ...
    @winrt_mixinmethod
    def add_MapChanged(self: win32more.Windows.Foundation.Collections.IObservableMap[WinRT_String, WinRT_String], vhnd: win32more.Windows.Foundation.Collections.MapChangedEventHandler[WinRT_String, WinRT_String]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_MapChanged(self: win32more.Windows.Foundation.Collections.IObservableMap[WinRT_String, WinRT_String], token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    Size = property(get_Size, None)
    MapChanged = event()
class ValueSet(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[MappingProtocol[WinRT_String, win32more.Windows.Win32.System.WinRT.IInspectable]]
    default_interface: win32more.Windows.Foundation.Collections.IPropertySet
    _classid_ = 'Windows.Foundation.Collections.ValueSet'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.Foundation.Collections.ValueSet.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.Foundation.Collections.ValueSet: ...
    @winrt_mixinmethod
    def add_MapChanged(self: win32more.Windows.Foundation.Collections.IObservableMap[WinRT_String, win32more.Windows.Win32.System.WinRT.IInspectable], vhnd: win32more.Windows.Foundation.Collections.MapChangedEventHandler[WinRT_String, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_MapChanged(self: win32more.Windows.Foundation.Collections.IObservableMap[WinRT_String, win32more.Windows.Win32.System.WinRT.IInspectable], token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def Lookup(self: win32more.Windows.Foundation.Collections.IMap[WinRT_String, win32more.Windows.Win32.System.WinRT.IInspectable], key: WinRT_String) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def get_Size(self: win32more.Windows.Foundation.Collections.IMap[WinRT_String, win32more.Windows.Win32.System.WinRT.IInspectable]) -> UInt32: ...
    @winrt_mixinmethod
    def HasKey(self: win32more.Windows.Foundation.Collections.IMap[WinRT_String, win32more.Windows.Win32.System.WinRT.IInspectable], key: WinRT_String) -> Boolean: ...
    @winrt_mixinmethod
    def GetView(self: win32more.Windows.Foundation.Collections.IMap[WinRT_String, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.Collections.IMapView[WinRT_String, win32more.Windows.Win32.System.WinRT.IInspectable]: ...
    @winrt_mixinmethod
    def Insert(self: win32more.Windows.Foundation.Collections.IMap[WinRT_String, win32more.Windows.Win32.System.WinRT.IInspectable], key: WinRT_String, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Boolean: ...
    @winrt_mixinmethod
    def Remove(self: win32more.Windows.Foundation.Collections.IMap[WinRT_String, win32more.Windows.Win32.System.WinRT.IInspectable], key: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def Clear(self: win32more.Windows.Foundation.Collections.IMap[WinRT_String, win32more.Windows.Win32.System.WinRT.IInspectable]) -> Void: ...
    @winrt_mixinmethod
    def First(self: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.Foundation.Collections.IKeyValuePair[WinRT_String, win32more.Windows.Win32.System.WinRT.IInspectable]]) -> win32more.Windows.Foundation.Collections.IIterator[win32more.Windows.Foundation.Collections.IKeyValuePair[WinRT_String, win32more.Windows.Win32.System.WinRT.IInspectable]]: ...
    Size = property(get_Size, None)
    MapChanged = event()
class VectorChangedEventHandler(Generic[T], MulticastDelegate):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _piid_ = Guid('{0c051752-9fbf-4c70-aa0c-0e4c82d9a761}')
    @winrt_commethod(3)
    def Invoke(self, sender: win32more.Windows.Foundation.Collections.IObservableVector[T], event: win32more.Windows.Foundation.Collections.IVectorChangedEventArgs) -> Void: ...


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Storage.StructuredStorage
JET_API_PTR = UIntPtr
JET_HANDLE = UIntPtr
JET_TABLEID = UIntPtr


make_ready(__name__)
